#
# spec file for package xfconf
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# gobject-introspection build fails with lto, see:
# https://gitlab.gnome.org/GNOME/gobject-introspection/-/merge_requests/247
%define _lto_cflags %{nil}

%bcond_with git
%define libname libxfconf-0-3

Name:           xfconf
Version:        4.18.3
Release:        bp156.2.4
Summary:        Simple Configuration Storage for Xfce
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/xfce/xfconf/start
Source0:        https://archive.xfce.org/src/xfce/xfconf/4.18/%{name}-%{version}.tar.bz2
Source1:        xfconf-query.1
Source100:      %{name}-rpmlintrc
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  perl(ExtUtils::Depends)
BuildRequires:  perl(ExtUtils::PkgConfig)
BuildRequires:  perl(Glib)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-2.0) >= 2.66.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.66.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0) >= 2.66.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gthread-2.0) >= 2.66.0
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.17.3
BuildRequires:  pkgconfig(vapigen)
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Recommends:     %{name}-lang = %{version}

%description
Xfconf is a simple client-server configuration storage and query system for the
Xfce desktop.

%package -n %{libname}
Summary:        Xfconf Shared Library
Group:          System/Libraries
Requires:       %{name} >= %{version}
Provides:       libxfce4mcs = %{version}
Obsoletes:      libxfce4mcs < %{version}

%description -n %{libname}
This package contains the xfconf shared library.

%package -n libxfconf-devel
Summary:        Development Files for xfconf
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Provides:       libxfce4mcs-devel = %{version}
Obsoletes:      libxfce4mcs-devel < %{version}
Provides:       xfce-mcs-manager-devel = %{version}
Obsoletes:      xfce-mcs-manager-devel < %{version}

%description  -n libxfconf-devel
This package contains the files needed for developing applications using
xfconf.

%package -n typelib-1_0-Xfconf-0
Summary:        Xfconf Shared Library
Group:          System/Libraries

%description -n typelib-1_0-Xfconf-0
GObject introspection bindings for Xfconf

%lang_package

%prep
%autosetup -p1

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode \
    --disable-static \
    --with-helper-path-prefix=%{_libexecdir} \
    --enable-vala=yes \
    --enable-gtk-doc
%else
%configure \
    --disable-static \
    --with-helper-path-prefix=%{_libexecdir} \
    --enable-vala=yes \
    --enable-gtk-doc
%endif
%make_build

%install
%make_install
install -D -p -m 644 %{SOURCE1} %{buildroot}%{_mandir}/man1/xfconf-query.1

rm -f %{buildroot}%{_libdir}/*.la \
    %{buildroot}%{_libdir}/gio/modules/*.la

%perl_process_packlist

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,ur_PK}

%find_lang %{name} %{?no_lang_C}

mkdir -p %{buildroot}%{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files
%doc AUTHORS NEWS TODO README.md
%license COPYING
%{_bindir}/xfconf-query
%dir %{_sysconfdir}/xdg/xfce4
%dir %{_sysconfdir}/xdg/xfce4/xfconf
%dir %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml
%dir %{_libexecdir}/xfce4
%dir %{_libexecdir}/xfce4/xfconf
%{_libexecdir}/xfce4/xfconf/xfconfd
%{_datadir}/dbus-1/services/org.xfce.Xfconf.service
%{_datadir}/bash-completion/completions/xfconf-query
%doc %{_mandir}/man1/xfconf-query.1*

%files -n %{libname}
%license COPYING
%{_libdir}/libxfconf-*.so.*
%{_libdir}/gio/modules/libxfconfgsettingsbackend.so

%files -n typelib-1_0-Xfconf-0
%{_libdir}/girepository-1.0/Xfconf-0.typelib

%files lang -f %{name}.lang

%files -n libxfconf-devel
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%doc %{_datadir}/gtk-doc/html/xfconf
%{_includedir}/xfce4
%{_libdir}/libxfconf-*.so
%{_libdir}/pkgconfig/libxfconf-*.pc
%{_datadir}/vala/vapi/libxfconf-0.*
%{_datadir}/gir-1.0/Xfconf-0.gir

%changelog
* Thu Nov  2 2023 Manfred Hollstein <manfred.h@gmx.net>
- Fix usage of %%%%lang_package
* Tue Oct 31 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.3
  * cache: Fix overwritten error
  * cache: Fix uncached value
- Fixes boo#1216682
* Tue Oct 17 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.2
  * Cache property-not-found responses in XfconfCache
  * Don't reset scheduled save timer on every write
  * xfconf-query: Sort channel list (-l or -m alone)
  * docs: Fix transfer type of xfconf_list_channels()
  * docs: Add clarification about bindings
- Use lang_package as bnc#513786 has been closed as fixed almost
  8 years ago.
* Mon Apr 17 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.1
  * Update copyright year
  * xfconfd: Lower warning level
  * docs: Fix xfconf_channel_get() transfer annotation
  * Update bug report address
  * docs: Fix unused declarations warning
  * docs: Properly enable GI docs
  * xfconfd: Fix check for "/" when building property name
  * xfconfd: Make xml backend case sensitive for channel names
  * Translation Updates
- Remove _service file
* Sun Dec 18 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.18.0
  * Bump requirements for Xfce 4.18
  * xfconf: Prevent Use-After-Free in GClosureNotify
* Fri Jan  8 2021 Maurizio Galli <maurizio.galli@gmail.com>
- %%{_sysconfdir}/xdg/xfce4 needs to be owned by the package
* Fri Jan  8 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Do not require exo-tools as built dependency. It is not supposed
  to depend on it.
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.0
  * Don't use shebang for bash completion file
  * Remove GLIB_CHECK_VERSION IFDEFs which are obsolete after glib bump
  * bump glib (and gio, gthread, etc) minimum to 2.50.0
  * remove last traces of xfconf-perl
  * Fix make distcheck and enable it on gitlab CI
  * Add README.md to EXTRA_DIST
* Mon Nov  9 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.1
  * Fix stray double-quote in bash-completion PKG_CONFIG invocation
  * Disable parallelism on all tests
  * Adds new README.md and updates AM_INIT_AUTOMAKE
  * xfconf-cache: Fix access to freed data (gxo#xfce/xfconf#16)
  * Translation Updates
- Update to version 4.15.0
  * Implement custom test driver
  * Use 'gsettings' as a common channel name for the GSetting backend
  * bxo#14789: Fix GSettings backend assertion error, when probed
    but not used
  * Enable GSettings backend build by default
  * Add Bash completion for xfconf-query
  * bxo#15960: Add some missing xfconf_shutdown() in xfconf-query
  * bxo#15951: Fix 'xfconf_get_error_quark' introspecting warning
  * Remove perl bindings
  * Fix vala binding in dist tarball
  * Translation Updates
- Removed xfconf-4.7.3-remove-rpath.patch
* Mon Nov  9 2020 Ali Abdallah <ali.abdallah@suse.com>
- Update to version 4.14.4
  * fix use after free bug in xfconf-cache (gxo#xfce/xfconf#16)
* Wed May  6 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.14.3
  * Use 'gsettings' as a common channel name for the GSetting backend
  * bxo#14789: Fix GSettings backend assertion error, when probed
    but not used.
  * bxo#15960: Add some missing xfconf_shutdown() in xfconf-query
  * bxo#15951: Fix 'xfconf_get_error_quark' introspecting warning
  * Translation updates
* Wed Feb 12 2020 Maurizio Galli <maurizio.galli@gmail.com>
- xfconfd needs to be a hard dependency to libxfconf (boo#1163214)
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Sun Aug 11 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.14.1
  * Release rebuild for libxfconf-0.deps
* Sun Aug 11 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.14.0
  * Translation updates
- Fixed up spec file
* Thu Jun 27 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to Version 4.13.8
  * Add support for GObject introspection and vala
  * Tests: Explicitly handle error reply from Ping method call
  * Disable perl bindings by default
  * Translation Updates
* Sat May 18 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.13.7
  - Bump glib version
  - bxo#15122: xfconf: disable gsettings backend by default
  - Fix compiler error -Wcast-function-type (GCC 8)
  - Fix this use of "defined" may not be portable
  - Update .gitignore
  - Fix warnings reported by GCC 8 (bxo#15112)
  - Added gdbus binding to gitignore, add post release git tag
  - Translation updates
- Fixed up dependencies
* Sat Apr 27 2019 maurizio.galli@gmail.com
- Update to version 4.13.6
  * Added .NOTPARALLEL to property change test (bxo#13840)
  * Implement an optional GSettings backend
- Changes from 4.13.5
  * Fix make distcheck, (bxo#14082)
  * Handle empty arrays by initializing the GValue to G_TYPE_PTR_ARRAY (bxo#13780)
- Changes from 4.13.4
  * Fix segfault in xfconf_cache_set_property_reply_handler when
    multiple calls are made (bug #13825)
  * Allow to store empty arrays (bug #13791)
  * Fix a path in xfconf_cache_set where the mutex isn't locked (bxo#13790)
- Changes from 4.13.3
  * Flush gdbus connection on xfconf_shutdown
  * Correctly use xfconf_shutdown in xfconf-query
  * Check for invalid GPtrArrays in the conversion
    from GValue to GVariant.
  * Fix some build issues in AM subdir-objects
  * Fix some autogen.sh warnings
    Better documentation processing.
- Changes from 4.13.2
  * Fix cache corruption due to a wrong g_value_unset call.
  * Update API gtk documentation
- Changes from 4.13.1
  * Revert the bump of libxfconf version from 0 to 1,
    to avoid massive changes in all xfce's components.
- Changes from 4.13.0
  * Port xfconf to gdbus
  * Bump libxfconf version from 0 to 1.
- Clean up spec file and dropped obsolete macros
- Added conditional %%bcond_with git for easier maintanance when using
  git master branch
* Fri Sep 22 2017 seife+obs@b1-systems.com
- do not package ChangeLog, NEWS is enough
* Sat Nov 26 2016 seife+obs@b1-systems.com
- update to version 4.12.1
  - add support for binding to GdkRGBAs (needed for gtk3 migration)
  - translation updates
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.0
  - allow :.,[]{} characters in property and channel names
    (bxo#11021)
  - fix make check when including perl bindings in the build
    (bxo#9556)
  - remove unneeded files
  - drop deprecated g_type_init() function
  - simplify checks
  - autotools updates
  - use new glib 2.32 mutex api
  - translation updates
* Thu Feb 19 2015 gber@opensuse.org
- update to version 4.11.0
  - allow :.,[]{} characters in property and channel names
    (bxo#11021)
  - fix make check when including perl bindings in the build
    (bxo#9556)
  - remove unneeded files.
  - drop deprecated g_type_init() function
  - simplify checks
  - autotools updates
  - use new glib 2.32 mutex api
  - translation updates
* Wed May  9 2012 gber@opensuse.org
- add versioned build dependency
* Sun Apr 29 2012 gber@opensuse.org
- update to version 4.10.0
  - don't emit property-changed on canceled calls
  - accept NULL as a string value
  - check abicheck.sh to be more portable
  - fix more deprecated g_value_set_char
  - explicitly link against gthread
  - drop deprecated g_mapped_file_free
  - translation updates
* Sat Apr 14 2012 gber@opensuse.org
- update to version 4.9.1
  - use LT_PREREQ and LT_INIT
  - UTF-8 check xfconf strings
  - do not dup strings in xfconf_channel_set_string
  - bump package dependency versions
  - fix comment in perl package info
  - don't use deprecated g_value_set_char
  - translation updates
- added xfconf-query manpage from Debian
* Sun Apr  8 2012 gber@opensuse.org
- update to version 4.9.0
  - use sh as interpreter in tests
  - add hook to skip the xfconf tests
  - make the abicheck work on Solaris and PPC64
  - fix licenses and use new FSF address
  - fix compiler warnings on Solaris
  - avoid GCC 4.6 compiler warning
  - add toggle option to xfconf-query
  - remove unusable import and export options from xfconf-query
  - translate all error strings in xfconf-query
  - cleanup Makefile.am files a bit
  - improve --version output in xfconf-query
  - cleanup #includes
  - drop usage of the G_CONST_RETURN macro
  - translation updates
* Thu Mar 29 2012 gber@opensuse.org
- corrected dependencies
- split of -lang subpackage
- specfile cleanup
* Fri Dec 23 2011 gber@opensuse.org
- remove workarounds for 11.2
- update to version 4.8.1
  - fix double free crash
  - allow installation of the helpers in a custom location
  - translation updates
- install xfconfd under %%_libexecdir
* Mon Jan 17 2011 gber@opensuse.org
- update to version 4.8.0
  - updated translations
* Tue Jan 11 2011 gber@opensuse.org
- make libxfconf-0-2-4 recommend xfconf
* Mon Dec 27 2010 gber@opensuse.org
- remove unecessary dynloader bs file
- use perl symbol for perl dependencies
- corrected groups
- improved summaries/descriptions
- added rpmlintrc
* Wed Dec 15 2010 prusnak@opensuse.org
- build perl bindings only on openSUSE 11.3 and newer
* Sun Dec  5 2010 prusnak@opensuse.org
- updated to 4.7.4
  * Don't enable options with --disable-<option> (bug #6820).
  * Updated translations: ug, sk, pt.
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Tue Nov 23 2010 gber@opensuse.org
- updated to 4.7.3
  * Disable cache singletons and improve some code now we know the
    tree is always empty during prefetch. This is only a
    disadvantage when creating multiple new channels with the same
    name, but in that case channels singletons should be used.
  * Lots of memory leaks plugged. Valgrind log is clean now.
  * Fix memory corruption during file loading and use mmap.
  * Properly handle dirty channels in the daemon and avoid
    excessive saving of channels.
  * Disable unimplemented code in the properties cache.
  * Steal values during cache prefetch to avoid a lot of copying.
  * Updated translations: hu.
  * Remove dangling nodes from the tree after a recursive remove.
  * Use a seconds timeout to reduce system wakeups.
  * Only print debug messages when compiled with debugging.
  * Merge xml files in reversed order (bug #6079).
  * Use g_strcmp0 for comparing strings.
  * Bump glib depenency to 2.18.
  * Silent the build.
  * Updated translations: pt_BR, nl, gl, fi, ru.
- cleanup
  * added summaries and descriptions
  * fixed build of Perl interface
  * fixed dependencies
* Tue Feb  2 2010 prusnak@suse.cz
- updated to 4.7.1
  * Remove dangling nodes from the tree after a recursive remove.
  * Use a seconds timeout to reduce system wakeups.
  * Only print debug messages when compiled with debugging.
  * Merge xml files in reversed order (bug #6079).
  * Use g_strcmp0 for comparing strings.
  * Bump glib depenency to 2.18.
  * Silent the build.
  * Updated translations: pt_BR, nl, gl, fi, ru.
* Wed Jan 13 2010 prusnak@suse.cz
- updated to 4.7.0
  * Add prefetching and caching support to XfconfChannel. Should speed
    things up a bit on app startup, and avoid blocking waiting on DBus
    in other cases.
  * New simpler (internal) handling of property bindings.
  * Use new xdt macros, this requires xfce-dev-tools 4.7.2.
  * New tests for object bindings.
  * Updated translations: es, kk, ca, sv, hu, ro, gl, ja, cs, lv, ast,
    zh_CN, ur, ur_PK, da, eu, pt.
* Mon Jul 20 2009 dominique-obs@leuenberger.net
- Follow change of %%%%{_libexecdir}
* Mon Apr 27 2009 prusnak@suse.cz
- replaced libxfcegui4 with libxfce4util in BuildRequires
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 4.6.1
* Mon Mar  9 2009 prusnak@suse.cz
- fix package names according to shared library policy
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 4.6.0 (Xfce 4.6.0 release)
* Mon Aug 18 2008 prusnak@suse.cz
- created package (version 4.5.80)
